@@ -1,7 +1,9 @@
 import dataclasses
 import enum
+import functools
 import io
 import typing
+import urllib.parse
 
 import dacite
 import yaml
@@ -30,6 +32,11 @@ class ResourceType(enum.Enum):
     GENERIC = 'generic'
 
 
+class ResourceRelation(enum.Enum):
+    LOCAL = 'local'
+    EXTERNAL = 'external'
+
+
 @dc(frozen=True)
 class ResourceAccess:
     type: AccessType
@@ -46,6 +53,38 @@ class GithubAccess(ResourceAccess):
     ref: str
     type: AccessType
 
+    def __post_init__(self):
+        parsed = self._normalise_and_parse_url()
+        if not len(parsed.path[1:].split('/')):
+            raise ValueError(f'{self.repoUrl=} must have exactly two path components')
+
+    @functools.lru_cache
+    def _normalise_and_parse_url(self):
+        parsed = urllib.parse.urlparse(self.repoUrl)
+        if not parsed.scheme:
+            # prepend dummy-schema to properly parse hostname and path (and rm it again later)
+            parsed = urllib.parse.urlparse('dummy://' + self.repoUrl)
+            parsed = urllib.parse.urlunparse((
+                '',
+                parsed.netloc,
+                parsed.path,
+                '',
+                '',
+                '',
+            ))
+            parsed = urllib.parse.urlparse(parsed)
+
+        return parsed
+
+    def repository_name(self):
+        return self._normalise_and_parse_url().path[1:].split('/')[1]
+
+    def org_name(self):
+        return self._normalise_and_parse_url().path[1:].split('/')[0]
+
+    def hostname(self):
+        return self._normalise_and_parse_url().hostname
+
 
 @dc(frozen=True)
 class HttpAccess(ResourceAccess):
@@ -87,12 +126,13 @@ class Resource:
     version: str
     type: ResourceType
     access: typing.Union[
-        ResourceAccess,
         OciAccess,
         GithubAccess,
         HttpAccess,
+        ResourceAccess,
         None
     ]
+    relation: ResourceRelation = ResourceRelation.LOCAL
     labels: typing.List[Label] = dataclasses.field(default_factory=list)
 
 
@@ -122,11 +162,19 @@ class Component:
 
     sources: typing.List[ComponentSource]
     componentReferences: typing.List[ComponentReference]
-    localResources: typing.List[Resource]
-    externalResources: typing.List[Resource]
+    resources: typing.List[Resource]
 
     labels: typing.List[Label] = dataclasses.field(default_factory=list)
 
+    def current_repository_ctx(self):
+        if not self.repositoryContexts:
+            return None
+        return self.repositoryContexts[-1]
+
+    # XXX rm asap - keep for backards-compat
+    localResources: typing.List[Resource] = dataclasses.field(default_factory=list)
+    externalResources: typing.List[Resource] = dataclasses.field(default_factory=list)
+
 
 @dc
 class ComponentDescriptor:
@@ -145,6 +193,7 @@ class ComponentDescriptor:
                     ResourceType,
                     SchemaVersion,
                     SourceType,
+                    ResourceRelation,
                 ]
             )
         )
